<?php

namespace Asadi\Grievance\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Grievance\Interfaces\GrievanceRepositoryInterface;
use Asadi\Grievance\Repositories\Presenter\GrievanceItemTransformer;

/**
 * Pubic API controller class.
 */
class GrievancePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Grievance\Interfaces\GrievanceRepositoryInterface $grievance
     *
     * @return type
     */
    public function __construct(GrievanceRepositoryInterface $grievance)
    {
        $this->repository = $grievance;
        parent::__construct();
    }

    /**
     * Show grievance's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $grievances = $this->repository
            ->setPresenter('\\Asadi\\Grievance\\Repositories\\Presenter\\GrievanceListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $grievances['code'] = 2000;
        return response()->json($grievances)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show grievance.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $grievance = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($grievance)) {
            $grievance         = $this->itemPresenter($module, new GrievanceItemTransformer);
            $grievance['code'] = 2001;
            return response()->json($grievance)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
