<?php

namespace Asadi\Grievance\Http\Controllers;
use Litepie\Grievance\Http\Requests\GrievanceRequest;
use Litepie\Grievance\Models\Grievance;

trait GrievanceWorkflow {
	
    /**
     * Workflow controller function for grievance.
     *
     * @param Model   $grievance
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(GrievanceRequest $request, Grievance $grievance, $step)
    {

        try {

            $grievance->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('grievance::grievance.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/grievance/grievance/' . $grievance->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/grievance/grievance/' . $grievance->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for grievance.
     *
     * @param Model   $grievance
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Grievance $grievance, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $grievance->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('grievance::grievance.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('grievance::admin.grievance.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('grievance::admin.grievance.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('grievance::admin.grievance.message', $data)->render();

        }

    }
}