<?php

namespace Asadi\Grievance\Policies;

use App\User;
use Asadi\Grievance\Models\Grievance;

class GrievancePolicy
{

    /**
     * Determine if the given user can view the grievance.
     *
     * @param User $user
     * @param Grievance $grievance
     *
     * @return bool
     */
    public function view(User $user, Grievance $grievance)
    {
        if ($user->canDo('grievance.grievance.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $grievance->user_id;
    }

    /**
     * Determine if the given user can create a grievance.
     *
     * @param User $user
     * @param Grievance $grievance
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('grievance.grievance.create');
    }

    /**
     * Determine if the given user can update the given grievance.
     *
     * @param User $user
     * @param Grievance $grievance
     *
     * @return bool
     */
    public function update(User $user, Grievance $grievance)
    {
        if ($user->canDo('grievance.grievance.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $grievance->user_id;
    }

    /**
     * Determine if the given user can delete the given grievance.
     *
     * @param User $user
     * @param Grievance $grievance
     *
     * @return bool
     */
    public function destroy(User $user, Grievance $grievance)
    {
        if ($user->canDo('grievance.grievance.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $grievance->user_id;
    }

    /**
     * Determine if the given user can verify the given grievance.
     *
     * @param User $user
     * @param Grievance $grievance
     *
     * @return bool
     */
    public function verify(User $user, Grievance $grievance)
    {
        if ($user->canDo('grievance.grievance.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('grievance.grievance.verify') 
        && $user->is('manager')
        && $grievance->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given grievance.
     *
     * @param User $user
     * @param Grievance $grievance
     *
     * @return bool
     */
    public function approve(User $user, Grievance $grievance)
    {
        if ($user->canDo('grievance.grievance.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
