<?php

namespace Asadi\Grievance\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Grievance\Models\Grievance;

class GrievanceAction
{
    /**
     * Perform the complete action.
     *
     * @param Grievance $grievance
     *
     * @return Grievance
     */
    public function complete(Grievance $grievance)
    {
        try {
            $grievance->status = 'complete';
            return $grievance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Grievance $grievance
     *
     * @return Grievance
     */public function verify(Grievance $grievance)
    {
        try {
            $grievance->status = 'verify';
            return $grievance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Grievance $grievance
     *
     * @return Grievance
     */public function approve(Grievance $grievance)
    {
        try {
            $grievance->status = 'approve';
            return $grievance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Grievance $grievance
     *
     * @return Grievance
     */public function publish(Grievance $grievance)
    {
        try {
            $grievance->status = 'publish';
            return $grievance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Grievance $grievance
     *
     * @return Grievance
     */
    public function archive(Grievance $grievance)
    {
        try {
            $grievance->status = 'archive';
            return $grievance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Grievance $grievance
     *
     * @return Grievance
     */
    public function unpublish(Grievance $grievance)
    {
        try {
            $grievance->status = 'unpublish';
            return $grievance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
